@@ -1,16 +1,23 @@
 import itertools
 from collections import defaultdict
-from typing import Any, Dict, List, Optional, Union
+from difflib import SequenceMatcher
+from typing import Any, Dict, List, Union
 
 import aiohttp
+import arrow
+from aiohttp import ClientSession
 from lxml.html import HTMLParser, fromstring
-from PicImageSearch import EHentai, Network
+from PicImageSearch import EHentai
 from PicImageSearch.model import EHentaiItem, EHentaiResponse
 from pyquery import PyQuery
 
 from .config import config
 from .utils import handle_img, shorten_url
 
+EHENTAI_HEADERS = (
+    {"Cookie": config.exhentai_cookies} if config.exhentai_cookies else None
+)
+
 
 class EHentaiResponseAioHttp:
     def __init__(self, resp_text: str, resp_url: str):
@@ -23,29 +30,24 @@ class EHentaiResponseAioHttp:
         self.url: str = resp_url
 
 
-async def ehentai_search(url: str, proxy: Optional[str], hide_img: bool) -> List[str]:
-    async with Network(proxies=proxy, cookies=config.exhentai_cookies) as client:
-        ex = bool(config.exhentai_cookies)
-        ehentai = EHentai(client=client)
-        if res := await ehentai.search(url, ex=ex):
-            if not res.raw:
-                # 如果第一次没找到，使搜索结果包含被删除的部分，并重新搜索
-                ehentai = EHentai(client=client, exp=True)
-                res = await ehentai.search(url, ex=ex)
-            return await search_result_filter(res, proxy, hide_img)
-        return ["EHentai 暂时无法使用"]
+async def ehentai_search(url: str, client: ClientSession, hide_img: bool) -> List[str]:
+    ex = bool(config.exhentai_cookies)
+    ehentai = EHentai(client=client)
+    if res := await ehentai.search(url, ex=ex):
+        if not res.raw:
+            # 如果第一次没找到，使搜索结果包含被删除的部分，并重新搜索
+            async with aiohttp.ClientSession(headers=EHENTAI_HEADERS) as session:
+                resp = await session.get(f"{res.url}&fs_exp=on", proxy=config.proxy)
+                res = EHentaiResponseAioHttp(await resp.text(), str(resp.url))
+        return await search_result_filter(res, hide_img)
+    return ["EHentai 暂时无法使用"]
 
 
-async def ehentai_title_search(
-    title: str, proxy: Optional[str], hide_img: bool
-) -> List[str]:
-    headers = {}
-    if cookies := config.exhentai_cookies:
-        headers["Cookie"] = cookies
-    url = "https://exhentai.org" if cookies else "https://e-hentai.org"
+async def ehentai_title_search(title: str, hide_img: bool) -> List[str]:
+    url = "https://exhentai.org" if config.exhentai_cookies else "https://e-hentai.org"
     params: Dict[str, Any] = {"f_search": title}
-    async with aiohttp.ClientSession(headers=headers) as session:
-        resp = await session.get(url, proxy=proxy, params=params)
+    async with aiohttp.ClientSession(headers=EHENTAI_HEADERS) as session:
+        resp = await session.get(url, proxy=config.proxy, params=params)
         if res := EHentaiResponseAioHttp(await resp.text(), str(resp.url)):
             if not res.raw:
                 # 如果第一次没找到，使搜索结果包含被删除的部分，并重新搜索
@@ -53,19 +55,28 @@ async def ehentai_title_search(
                 params["f_sname"] = "on"
                 params["f_stags"] = "on"
                 params["f_sh"] = "on"
-                resp = await session.get(url, proxy=proxy, params=params)
+                resp = await session.get(url, proxy=config.proxy, params=params)
                 res = EHentaiResponseAioHttp(await resp.text(), str(resp.url))
-            return await search_result_filter(res, proxy, hide_img)
+            # 只保留标题和搜索关键词相关度较高的结果，以此来提高准确度
+            if res.raw and (
+                filtered := [
+                    i
+                    for i in res.raw
+                    if SequenceMatcher(None, title, i.title).ratio() > 0.6
+                ]
+            ):
+                res.raw = filtered
+            return await search_result_filter(res, hide_img)
         return ["EHentai 暂时无法使用"]
 
 
 async def search_result_filter(
     res: Union[EHentaiResponse, EHentaiResponseAioHttp],
-    proxy: Optional[str],
     hide_img: bool,
 ) -> List[str]:
     if not res.raw:
-        return ["EHentai 搜索结果为空"]
+        _url = await shorten_url(res.url)
+        return [f"EHentai 搜索结果为空\n搜索页面：{_url}"]
     # 尽可能过滤掉非预期结果(大概
     priority = defaultdict(lambda: 0)
     priority["Image Set"] = 1
@@ -91,15 +102,16 @@ async def search_result_filter(
         selected_res = res.raw[0]
 
     thumbnail = await handle_img(
-        selected_res.thumbnail, proxy, hide_img, config.exhentai_cookies
+        selected_res.thumbnail, hide_img, cookies=config.exhentai_cookies
     )
+    date = arrow.get(selected_res.date).to("Asia/Shanghai").format("YYYY-MM-DD HH:mm")
     _url = await shorten_url(res.url)
     res_list = [
         "EHentai 搜索结果",
         thumbnail,
         selected_res.title,
         f"类型：{selected_res.type}",
-        f"日期：{selected_res.date}",
+        f"日期：{date}",
         f"来源：{selected_res.url}",
         f"搜索页面：{_url}",
     ]
